<a name="1.0.0"></a> ### 1.0.0 (2017-03-29)

#### Features
* **rest** HTTP/REST client
* **seneca** Seneca client
* **null** Null client for testing
* **unit tests** Unit tests using Mocha and Matcha

#### Breaking Changes
No breaking changes since this is the first version

#### Bug Fixes
No fixes in this version

